@@ -11,20 +11,19 @@ from .models.chat import (
     Content,
     BaseMessage,
 )
-from .models.chat_item import ChatItem, OuterContextItem, InnerContextItem, ReplicaItem
 from .models.enums import MTRSLabelEnum, DiagnosticsXMLTagEnum, MTRSXMLTagEnum, DoctorChoiceXMLTagEnum
 from .models.tracks import TrackInfo, DomainInfo
 from .models.widget import Widget
 from .utils import make_session_id, chunked
 from .xml_parser import XMLParser
 from .utils_import import load_main_objects
+from .decorators_maybe_lru_cache import maybe_lru_cache
 
 __all__ = [
     "AIMessage",
     "Base",
     "BaseMessage",
     "Chat",
-    "ChatItem",
     "ChatMessage",
     "Content",
     "Context",
@@ -33,12 +32,9 @@ __all__ = [
     "DomainInfo",
     "FileStorage",
     "HumanMessage",
-    "InnerContextItem",
     "MTRSLabelEnum",
     "MTRSXMLTagEnum",
     "MiscMessage",
-    "OuterContextItem",
-    "ReplicaItem",
     "ResourceId",
     "TrackInfo",
     "Widget",
@@ -47,4 +43,5 @@ __all__ = [
     "load_main_objects",
     "make_content",
     "make_session_id",
+    "maybe_lru_cache",
 ]
