@@ -111,11 +111,11 @@ class FileStorage:
 
     def is_file(self, resource_id: ResourceId | None) -> bool:
         path = self._get_path(resource_id)
-        return path and path.suffix != SUFFIX_DIR
+        return bool(path and path.suffix != SUFFIX_DIR)
 
     def is_dir(self, resource_id: ResourceId | None) -> bool:
         path = self._get_path(resource_id)
-        return path and path.suffix == SUFFIX_DIR
+        return bool(path and path.suffix == SUFFIX_DIR)
 
     def get_dtype(self, resource_id: ResourceId | None) -> str | None:
         return resource_id and resource_id.rsplit(".")[-1].lower()
