@@ -1,6 +1,6 @@
 from typing import Self, Literal
 
-from more_itertools import chunked
+from mmar_mapi.utils import chunked
 from pydantic import BaseModel, model_validator
 
 
@@ -26,9 +26,17 @@ class Widget(BaseModel):
     def make_inline_buttons(ibuttons: dict[str, str], by=1) -> "Widget":
         return _make_inline_buttons(ibuttons=ibuttons, by=by)
 
+    @staticmethod
+    def make_buttons(buttons: list[str], by=1) -> "Widget":
+        return _make_buttons(buttons=buttons, by=1)
+
 
 def _make_inline_buttons(ibuttons: dict[str, str], by=1) -> "Widget":
     ibs0 = [f"{key}:{val}" for key, val in ibuttons.items()]
-    ibs = list(chunked(ibs0, n=by))
-    res = Widget(ibuttons=ibs)
+    res = Widget(ibuttons=list(chunked(ibs0, n=by)))
+    return res
+
+
+def _make_buttons(buttons: list[str], by=1) -> "Widget":
+    res = Widget(buttons=list(chunked(buttons, n=by)))
     return res
